Tidy up a vector of stan names into a data frame.
tidy_stanpars(stannames, labs = NULL, ...)Character vector of stan names.
Optional. Character vector for what indices meaningfully pertain to. E.g., c("Factor", "Item") for an FxJ matrix.
Optional. Named vectors of labels corresponding to indices. E.g., if labs = "Item", and you include Item = colnames(model_matrix), then the indices (numeric) are replaced by the name in the supplied vector. E.g., the numeric i will be replaced by the i-th name.
Data frame containing parameters and the (optionally named) indices.